NAME = "openai_commands"

ICON = "🛠️"

DESCRIPTION = f"{ICON} a command interface to the OpenAI API."

VERSION = "3.178.1"

REPO_NAME = "openai-commands"

MARQUEE = "https://github.com/kamangir/openai-commands/raw/main/assets/carrot.png"
